###################
#EG JUNE 2020# 
#R script to analyze age-related change 
#in human, chimpanzee, and rhesus macaque 
#methylation microarray (EPIC) data
###################

###################
#A : SET-UP
###################
#Harriet
setwd("/aging")

library(ChAMP)
library(missMethyl)
library(ggplot2)
#library(IlluminaHumanMethylation450kanno.ilmn12.hg19)
library(data.table)
library(dplyr)
library(tibble)
library(scales)
library(cowplot)

###################
#B : READ IN AND PREPROCESS DATA
###################
#Harriet
#for analyzing all the data, including macaque together:
baseDir <- "/combined_data_HCM"

#load and filter data
#This removes probes:
#with intensities with sig detection p-vals
#with <3 beads in at least 5% of samples per probe
#non-CpG probes
#containing known SNPs
#on X and Y chr
#probes that align to more than one place in the genome
#combined data
data <- champ.load(baseDir,arraytype="EPIC", detPcut = 0.5)

#put underscore in species names
data$pd$Species <- sub(" ", "_", data$pd$Species)

#2 : normalize
norm.beta <- champ.norm(beta = data$beta,method="BMIQ")

#3 : subset by species competent probes on EPIC
#read in chimp competent probes
chimpCompProbes = readLines("Needhamsen_Chimpanzee_Compentent_Probes.txt")
#read in macaque competent probes
macaCompProbes = readLines("macaque_competent_EPIC_probes.txt")
#overlap chimp and macaque competent probes to use for downstream analysis
chimpmacaCompProbes = intersect(chimpCompProbes, macaCompProbes)

#rm redundant
rm(macaCompProbes)

#subset beta
comp.beta <- subset(norm.beta, rownames(norm.beta) %in% chimpmacaCompProbes)

#54 : remove genotyping probes for DMRcate
filtered.comp.beta <- rmSNPandCH(comp.beta, dist=2, mafcut=0.05)

#6 : split into DLPFC and CRBM data
DLPFC_pd <- subset(data$pd, data$pd$Region == "DLPFC")
CRBM_pd <- subset(data$pd, data$pd$Region == "CRBM")

DLPFC_Beta_HCM <- subset(filtered.comp.beta, select = DLPFC_pd$Sample_Name)
CRBM_Beta_HCM <- subset(filtered.comp.beta, select = CRBM_pd$Sample_Name)

#recommended: delete now-redundant objects
rm(comp.beta)
rm(filtered.comp.beta)


###################
#C : DIFFERENTIAL METHYLATION
###################
#I: DLPFC
###################
human_DLPFC_samples <- c("19a","20a","21a","22a","23a","24a","26a")
human_DLPFC_sample_ages <- c("Young","Young","Young","Young","Old","Old","Old")

chimp_DLPFC_samples <- c("1a","2a","3a","4a","5a","6a","7a","8a")
chimp_DLPFC_sample_ages <- c("Young","Young","Young","Young","Old","Old","Old","Old")

rhesus_DLPFC_samples <- c("10a","11a","12a","13a","14a","15a","9a")
rhesus_DLPFC_samples_ages <- c("Young","Young","Young","Old","Old","Old","Young")

humanBeta_DLPFC <- subset(DLPFC_Beta_HCM, select = human_DLPFC_samples)
chimpBeta_DLPFC <- subset(DLPFC_Beta_HCM, select = chimp_DLPFC_samples)
rhesusBeta_DLPFC <- subset(DLPFC_Beta_HCM, select = rhesus_DLPFC_samples)

#write data for records
write.table(humanBeta_DLPFC, "humanBeta_DLPFC.txt", sep = "\t")
write.table(chimpBeta_DLPFC, "chimpBeta_DLPFC.txt", sep = "\t")
write.table(rhesusBeta_DLPFC, "rhesusBeta_DLPFC.txt", sep = "\t")

#Identify aDMPs & aDMPs
#ID aDMPs
#############
#a : human
#############
#1 : set up model design and contrasts
human_design <- model.matrix(~0 + human_DLPFC_sample_ages)
colnames(human_design) <- c("old", "young")
human_contr <- makeContrasts(old-young, levels = human_design)

#2 : first calculate basic stats and annotate probes
DLPFC_human_stats <- data.frame(matrix(ncol = 0, nrow = length(rownames(humanBeta_DLPFC))))
rownames(DLPFC_human_stats) <- rownames(humanBeta_DLPFC)
DLPFC_human_stats$young_mean <- rowMeans(humanBeta_DLPFC[,human_DLPFC_samples[1:4]])
DLPFC_human_stats$old_mean <- rowMeans(humanBeta_DLPFC[,human_DLPFC_samples[5:7]])
DLPFC_human_stats$deltaBeta <- abs(DLPFC_human_stats$young_mean - DLPFC_human_stats$old_mean)

#combine with illumina annotations (leaving off that added column called "row.names")
DLPFC_human_stats_info <- merge(DLPFC_human_stats, probe.features, by = "row.names")
rownames(DLPFC_human_stats_info) <- DLPFC_human_stats_info$Row.names
DLPFC_human_stats_info <- DLPFC_human_stats_info[2:15]

#3 : lmFit
human_DLPFC_fit <- lmFit(humanBeta_DLPFC, human_design)
human_DLPFC_fit2 <- contrasts.fit(human_DLPFC_fit, human_contr)
human_DLPFC_efit <- eBayes(human_DLPFC_fit2)

#get info for all regardless of p-value
human_DLPFC_DMP_table <- topTable(human_DLPFC_efit, p.value = 1, number = length(rownames(humanBeta_DLPFC)))

#merge DMP info with CpG info
human_DLPFC_aDMP_info <- merge(DLPFC_human_stats_info, human_DLPFC_DMP_table, by = "row.names")
#changing this colname back and adding CpGs back again to row names
rownames(human_DLPFC_aDMP_info) <- human_DLPFC_aDMP_info$Row.names
human_DLPFC_aDMP_info <- human_DLPFC_aDMP_info[2:length(colnames(human_DLPFC_aDMP_info))]

#4 : now filter by p-value and by deltaBeta > 0.15
sig_human_DLPFC_aDMPs <- subset(human_DLPFC_aDMP_info, human_DLPFC_aDMP_info$adj.P.Val <= 0.05 & abs(human_DLPFC_aDMP_info$deltaBeta) >= 0.15)

#write table of significant aDMPs
write.table(sig_human_DLPFC_aDMPs, "sig_human_DLPFC_aDMPs.txt", sep = "\t")

#############
#b : chimp
#############
#1 : set up model design and contrasts
chimp_design <- model.matrix(~0 + chimp_DLPFC_sample_ages)
colnames(chimp_design) <- c("old", "young")
chimp_contr <- makeContrasts(old-young, levels = chimp_design)

#2 : first calculate basic stats and annotate probes
DLPFC_chimp_stats <- data.frame(matrix(ncol = 0, nrow = length(rownames(chimpBeta_DLPFC))))
rownames(DLPFC_chimp_stats) <- rownames(chimpBeta_DLPFC)
DLPFC_chimp_stats$young_mean <- rowMeans(chimpBeta_DLPFC[,chimp_DLPFC_samples[1:4]])
DLPFC_chimp_stats$old_mean <- rowMeans(chimpBeta_DLPFC[,chimp_DLPFC_samples[5:8]])
DLPFC_chimp_stats$deltaBeta <- abs(DLPFC_chimp_stats$young_mean - DLPFC_chimp_stats$old_mean)

#combine with illumina annotations (leaving off that added column called "row.names" that it adds)
DLPFC_chimp_stats_info <- merge(DLPFC_chimp_stats, probe.features, by = "row.names")
rownames(DLPFC_chimp_stats_info) <- DLPFC_chimp_stats_info$Row.names
DLPFC_chimp_stats_info <- DLPFC_chimp_stats_info[2:15]

#3 : lmFit
chimp_DLPFC_fit <- lmFit(chimpBeta_DLPFC, chimp_design)
chimp_DLPFC_fit2 <- contrasts.fit(chimp_DLPFC_fit, chimp_contr)
chimp_DLPFC_efit <- eBayes(chimp_DLPFC_fit2)
chimp_DLPFC_DMP_table <- topTable(chimp_DLPFC_efit, p.value = 1, number = length(rownames(chimpBeta_DLPFC)))

#merge DMP info with CpG info
chimp_DLPFC_aDMP_info <- merge(DLPFC_chimp_stats_info, chimp_DLPFC_DMP_table, by = "row.names")
#changing this colname back and adding CpGs back again to row names
rownames(chimp_DLPFC_aDMP_info) <- chimp_DLPFC_aDMP_info$Row.names
chimp_DLPFC_aDMP_info <- chimp_DLPFC_aDMP_info[2:length(colnames(chimp_DLPFC_aDMP_info))]

#4 : pull out the sig DMPs that have a deltaBeta > 0.15
sig_chimp_DLPFC_aDMPs <- subset(chimp_DLPFC_aDMP_info, chimp_DLPFC_aDMP_info$adj.P.Val <= 0.05 & abs(chimp_DLPFC_aDMP_info$deltaBeta) >= 0.15)
write.table(sig_chimp_DLPFC_aDMPs, "sig_chimp_DLPFC_aDMPs.txt", sep = "\t")

#############
#c : rhesus
#############
#1 : set up model design and contrasts
rhesus_design <- model.matrix(~0 + rhesus_DLPFC_samples_ages)
colnames(rhesus_design) <- c("old", "young")
rhesus_contr <- makeContrasts(old-young, levels = rhesus_design)

#2 : first calculate basic stats and annotate probes
DLPFC_rhesus_stats <- data.frame(matrix(ncol = 0, nrow = length(rownames(rhesusBeta_DLPFC))))
rownames(DLPFC_rhesus_stats) <- rownames(rhesusBeta_DLPFC)
DLPFC_rhesus_stats$young_mean <- rowMeans(rhesusBeta_DLPFC[,rhesus_DLPFC_samples[c(7,1:3)]])
DLPFC_rhesus_stats$old_mean <- rowMeans(rhesusBeta_DLPFC[,rhesus_DLPFC_samples[4:6]])
DLPFC_rhesus_stats$deltaBeta <- abs(DLPFC_rhesus_stats$young_mean - DLPFC_rhesus_stats$old_mean)

#combine with illumina annotations (leaving off that added column called "row.names" that it adds)
DLPFC_rhesus_stats_info <- merge(DLPFC_rhesus_stats, probe.features, by = "row.names")
rownames(DLPFC_rhesus_stats_info) <- DLPFC_rhesus_stats_info$Row.names
DLPFC_rhesus_stats_info <- DLPFC_rhesus_stats_info[2:15]

#3 : lmFit
rhesus_DLPFC_fit <- lmFit(rhesusBeta_DLPFC, rhesus_design)
rhesus_DLPFC_fit2 <- contrasts.fit(rhesus_DLPFC_fit, rhesus_contr)
rhesus_DLPFC_efit <- eBayes(rhesus_DLPFC_fit2)
rhesus_DLPFC_DMP_table <- topTable(rhesus_DLPFC_efit, p.value = 1, number = length(rownames(rhesusBeta_DLPFC)))

#merge DMP info with CpG info
rhesus_DLPFC_aDMP_info <- merge(DLPFC_rhesus_stats_info, rhesus_DLPFC_DMP_table, by = "row.names")
#changing this colname back and adding CpGs back again to row names since merge stupidly removes row names and alters the colname
rownames(rhesus_DLPFC_aDMP_info) <- rhesus_DLPFC_aDMP_info$Row.names
rhesus_DLPFC_aDMP_info <- rhesus_DLPFC_aDMP_info[2:length(colnames(rhesus_DLPFC_aDMP_info))]

#4 : pull out the sig DMPs that have a deltaBeta > 0.15
sig_rhesus_DLPFC_aDMPs <- subset(rhesus_DLPFC_aDMP_info, rhesus_DLPFC_aDMP_info$adj.P.Val <= 0.05 & abs(rhesus_DLPFC_aDMP_info$deltaBeta) >= 0.15)
write.table(sig_rhesus_DLPFC_aDMPs, "sig_rhesus_DLPFC_aDMPs.txt", sep = "\t")

#rm redundant objects
rm(human_DLPFC_DMP_table)
rm(chimp_DLPFC_DMP_table)
rm(rhesus_DLPFC_DMP_table)
rm(DLPFC_human_stats)
rm(DLPFC_chimp_stats)
rm(DLPFC_rhesus_stats)

#################
#d : see whether there is overlap among aDMPs in species
#################
#CM
intersect(rownames(sig_rhesus_DLPFC_aDMPs), rownames(sig_chimp_DLPFC_aDMPs))
#HM
intersect(rownames(sig_rhesus_DLPFC_aDMPs), rownames(sig_human_DLPFC_aDMPs))
#HC
intersect(rownames(sig_human_DLPFC_aDMPs), rownames(sig_chimp_DLPFC_aDMPs))

#################
#e : identify & visualize DMRs
#################
#1 : cpg.annotate
human_DLPFC_DMRcate_annotation <- cpg.annotate("array", humanBeta_DLPFC, arraytype = "EPIC", analysis.type = "differential", design = human_design, contrasts = TRUE, cont.matrix = human_contr, coef = "old - young")
chimp_DLPFC_DMRcate_annotation <- cpg.annotate("array", chimpBeta_DLPFC, arraytype = "EPIC", analysis.type = "differential", design = chimp_design, contrasts = TRUE, cont.matrix = chimp_contr, coef = "old - young")
rhesus_DLPFC_DMRcate_annotation <- cpg.annotate("array", rhesusBeta_DLPFC, arraytype = "EPIC", analysis.type = "differential", design = rhesus_design, contrasts = TRUE, cont.matrix = rhesus_contr, coef = "old - young")

#2 : DMRcate
human_DLPFC_DMRcate_DMRs <- dmrcate(human_DLPFC_DMRcate_annotation, lambda=1000, C=2, min.cpgs = 5, betacutoff = .15)
chimp_DLPFC_DMRcate_DMRs <- dmrcate(chimp_DLPFC_DMRcate_annotation, lambda=1000, C=2, min.cpgs = 5, betacutoff = .15)
rhesus_DLPFC_DMRcate_DMRs <- dmrcate(rhesus_DLPFC_DMRcate_annotation, lambda=1000, C=2, min.cpgs = 5, betacutoff = .15)

#3 : visualize human DMRs (none in chimp or rhesus, so skipping)
###########
#i : format DMRs
human_DLPFC_DMRs <- data.frame(matrix(unlist(strsplit(human_DLPFC_DMRcate_DMRs$results$coord, split = "-|:")), nrow = length(human_DLPFC_DMRcate_DMRs$results$coord), byrow = T))
#add col names
colnames(human_DLPFC_DMRs) <- c("CHR", "start", "end")
#remove text for chr
human_DLPFC_DMRs$CHR <- gsub("[a-zA-Z ]", "", human_DLPFC_DMRs$CHR)

#ii : pull out CpGs in range of each DMR
f_range = function(x, output){subset(human_DLPFC_aDMP_info, human_DLPFC_aDMP_info$CHR == as.numeric(x[1]) & human_DLPFC_aDMP_info$MAPINFO >= as.numeric(x[2]) & human_DLPFC_aDMP_info$MAPINFO <= as.numeric(x[3]))}
human_DLPFC_DMR_ranges <- apply(human_DLPFC_DMRs, 1, f_range)

#get a vector of DMR names
human_DLPFC_DMR_numbers <- sapply(1:length(human_DLPFC_DMR_ranges), function(x) paste0("DMR_",x))

#assign names to list of DMR ranges
names(human_DLPFC_DMR_ranges) <- human_DLPFC_DMR_numbers

#iii : get the gene and plot titles info for each DMR
human_DLPFC_DMR_genes <- lapply(1:length(human_DLPFC_DMR_ranges), function(x){unique(as.character(human_DLPFC_DMR_ranges[[x]]$gene))})
human_DLPFC_DMR_titles <- lapply(1:length(human_DLPFC_DMR_ranges), function(x){capture.output(cat(human_DLPFC_DMR_genes[[x]], sep = "/"))})

#iv : create tables of DMRs and CpGs in DMRs for export
human_DLPFC_DMRs_CpG_Table <- do.call(rbind.data.frame, human_DLPFC_DMR_ranges)
human_DLPFC_DMRs_CpG_Table$CpG <- gsub("^.*\\.", "", rownames(human_DLPFC_DMRs_CpG_Table))
human_DLPFC_DMRs_CpG_Table$DMR <- gsub("\\..*", "", rownames(human_DLPFC_DMRs_CpG_Table))

#get cols in the correct order
human_DLPFC_DMRs_CpG_Table <- human_DLPFC_DMRs_CpG_Table[,c(length(colnames(human_DLPFC_DMRs_CpG_Table)),length(colnames(human_DLPFC_DMRs_CpG_Table))-1,1:(length(colnames(human_DLPFC_DMRs_CpG_Table))-2))]
write.table(human_DLPFC_DMRs_CpG_Table, "human_DLPFC_DMRs_CpG_Table.txt", sep = "\t")

#write the DMRs
human_DLPFC_DMR_coords <- lapply(1:length(human_DLPFC_DMR_ranges), function(x){data.frame("DMR" = names(human_DLPFC_DMR_ranges[x]), "CHR" = unique(human_DLPFC_DMR_ranges[[x]]$CHR), "start" = min(human_DLPFC_DMR_ranges[[x]]$MAPINFO), "end" = max(human_DLPFC_DMR_ranges[[x]]$MAPINFO), "gene" = paste(human_DLPFC_DMR_genes[[x]],sep = ",",collapse=","))})
#to get this from a list to dataframe
human_DLPFC_DMRs_table <- do.call(rbind.data.frame, human_DLPFC_DMR_coords)
write.table(human_DLPFC_DMRs_table, "human_DLPFC_DMRs.txt", sep = "\t")

#combine the chromosome info and coordinates as unique DMR description
human_DLPFC_DMR_collapsed_coords <- apply(human_DLPFC_DMRs, 1, function(x) {human_DLPFC_DMR_collapsed_ranges <- c(paste0(trimws(x[2]),":",trimws(x[3]),"-",trimws(x[4]), sep = ""))})
names(human_DLPFC_DMR_collapsed_coords) <- names(human_DLPFC_DMR_ranges)

#v : pull out any sig uniquely human methylated probes within these DMR ranges
f_human_DLPFC_range_sig = function(x, output){subset(sig_human_DLPFC_aDMPs, sig_human_DLPFC_aDMPs$CHR == as.numeric(x[1]) & sig_human_DLPFC_aDMPs$MAPINFO >= as.numeric(x[2]) & sig_human_DLPFC_aDMPs$MAPINFO <= as.numeric(x[3]))}
human_DLPFC_DMR_ranges_sig <- apply(human_DLPFC_DMRs, 1, f_human_DLPFC_range_sig)
names(human_DLPFC_DMR_ranges_sig) <- human_DLPFC_DMR_numbers

#vi : pull put beta values for CpGs in those ranges
f_human_DLPFC_beta <- function(x, output){data.frame(humanBeta_DLPFC[rownames(x),])}
human_DLPFC_DMR_beta <- lapply(human_DLPFC_DMR_ranges, f_human_DLPFC_beta)

#vii : create annotate df
f_info <- function(x, output){data.frame("CpG" = rownames(x), "Coordinates" = x$MAPINFO, "Feature" = x$feature)}
human_DLPFC_DMR_info <- lapply(human_DLPFC_DMR_ranges, f_info)

#viii : reshape and integrate beta and info data 
human_DLPFC_DMR_beta_info <- lapply(1:length(human_DLPFC_DMR_ranges), function(x){data.frame(t(data.frame(human_DLPFC_DMR_beta[x]))) %>% add_column(human_DLPFC_sample_ages) %>% reshape2::melt() %>% setNames(., c("age","CpG","beta")) %>% right_join(human_DLPFC_DMR_info[[x]], by = "CpG")})

#reorder
human_DLPFC_DMR_beta_info <- lapply(1:length(human_DLPFC_DMR_ranges), function(x){human_DLPFC_DMR_beta_info[[x]][order(human_DLPFC_DMR_beta_info[[x]][,"Coordinates"]),]})

#ix : create plots
#plot 1 -  beta values and loess lines by age class 
human_DLPFC_DMR_plots_1 <- lapply(1:length(human_DLPFC_DMR_ranges), function(x){ggplot() + geom_point(data = human_DLPFC_DMR_beta_info[[x]], aes(x = Coordinates, y = beta, color = age, group = age), position = position_dodge(width = 0.3), size = 1) + theme_bw() + stat_smooth(data = human_DLPFC_DMR_beta_info[[x]], aes(x = Coordinates, y = beta, color = age, group = age), method = "glm", geom ='line', formula = y ~ ns(x, 3), alpha=0.5, se=FALSE, size = 1, span = 1) + ggtitle(paste0(names(human_DLPFC_DMR_ranges)[x],":",human_DLPFC_DMR_titles[[x]],"\nchr",unique(human_DLPFC_DMR_ranges[[x]]$CHR),":",min(human_DLPFC_DMR_ranges[[x]]$MAPINFO),"-",max(human_DLPFC_DMR_ranges[[x]]$MAPINFO))) + theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), plot.title = element_text(hjust = 0.5)) + xlab("Chromosomal coordinate") + ylab("Proportion methylated") + ylim(-0.015,1) + scale_colour_manual(values = c("#F8766D","#BF80FF")) + scale_y_continuous(limit = c(-0.015, 1.015), oob = squish) + theme(plot.margin = unit(c(1, 6.55, 1, 1), 'lines'), legend.position = c(1.14, 0.83))})

#plot 2 for all - map feature annotations and significantly uniquely human methylated CpGs
#has to have transparent background so that they can overlap
#define manual color scale for features
feature_breaks = c("TSS1500","TSS200","5'UTR","1stExon","Body","3'UTR","IGR")
feature_labels = c("TSS1500" = "TSS 1500","TSS200" = "TSS 200","5'UTR" = "5' UTR","1stExon" = "1st Exon","Body" = "Body","3'UTR" = "3' UTR", "IGR" = "IGR")
feature_values = c("TSS1500" = "#F8766D","TSS200" = "#B79F00","5'UTR" = "#00BA38","1stExon" = "#00BFC4","Body" = "#619CFF","3'UTR" = "#F564E3", "IGR" = "gray66")
human_DLPFC_DMR_plots_2 <- lapply(1:length(human_DLPFC_DMR_ranges), function(x){ggplot() + geom_point(data = human_DLPFC_DMR_beta_info[[x]][order(human_DLPFC_DMR_beta_info[[x]][,"Feature"]),], aes(x = Coordinates, y=-0.015, color = Feature), size = 2, shape = "square") + geom_path(data = human_DLPFC_DMR_beta_info[[x]], aes(x = Coordinates, y = -0.015, color = Feature, group = interaction(rleid(human_DLPFC_DMR_beta_info[[x]]$Feature), Feature)), size = 2.4) + ylim(-0.015,1.015) + theme_bw() + ggtitle(paste0(names(human_DLPFC_DMR_ranges)[x],":",human_DLPFC_DMR_titles[[x]],"\nchr",unique(human_DLPFC_DMR_ranges[[x]]$CHR),":",min(human_DLPFC_DMR_ranges[[x]]$MAPINFO),"-",max(human_DLPFC_DMR_ranges[[x]]$MAPINFO))) + theme(plot.title = element_text(hjust = 0.5)) + xlab("Chromosomal coordinate") + ylab("Proportion methylated") + theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), panel.background = element_rect(fill = "transparent",colour = NA), plot.background = element_rect(fill = "transparent", colour = NA), plot.margin = unit(c(1, 6.55, 1, 1), 'lines'), legend.position = c(1.14, 0.32)) + scale_color_manual(values = feature_values, labels = feature_labels, breaks = feature_breaks) + {if(nrow(data.frame(human_DLPFC_DMR_ranges_sig[[x]])) > 0)geom_point(aes(x = human_DLPFC_DMR_ranges_sig[[x]]$MAPINFO, y = 1), shape = 8, size = 1)}})

#align and combine plots
human_DLPFC_DMR_aligned_plots <- lapply(1:length(human_DLPFC_DMR_ranges), function(x){align_plots(human_DLPFC_DMR_plots_1[[x]], human_DLPFC_DMR_plots_2[[x]], align = "hv", axis = "tblr")})
human_DLPFC_DMR_combined_plots <- lapply(1:length(human_DLPFC_DMR_ranges), function(x){ggdraw(human_DLPFC_DMR_aligned_plots[[x]][[1]]) + draw_plot(human_DLPFC_DMR_aligned_plots[[x]][[2]])})

#x : save plots
lapply(1:length(human_DLPFC_DMR_ranges), function(x){ggsave(filename=paste("human_DLPFC_",names(human_DLPFC_DMR_ranges[x]),"_",capture.output(cat(human_DLPFC_DMR_genes[[x]], sep = "_")),"_plot.png",sep=""), plot=human_DLPFC_DMR_combined_plots[[x]], height = 4, width = 7)})

####################
#II: CRBM
####################
human_CRBM_samples <- c("19d","20d","21d","22d","23d","24d","26d")
human_CRBM_sample_ages <- c("Young","Young","Young","Young","Old","Old","Old")

chimp_CRBM_samples <- c("1d","2d","3d","4d","5d","6d","7d","8d")
chimp_CRBM_sample_ages <- c("Young","Young","Young","Young","Old","Old","Old","Old")

rhesus_CRBM_samples <- c("10d","11d","12d","13d","14d","15d","9d")
rhesus_CRBM_samples_ages <- c("Young","Young","Young","Old","Old","Old","Young")

humanBeta_CRBM <- subset(CRBM_Beta_HCM, select = human_CRBM_samples)
chimpBeta_CRBM <- subset(CRBM_Beta_HCM, select = chimp_CRBM_samples)
rhesusBeta_CRBM <- subset(CRBM_Beta_HCM, select = rhesus_CRBM_samples)

#write data for records
write.table(humanBeta_CRBM, "humanBeta_CRBM.txt", sep = "\t")
write.table(chimpBeta_CRBM, "chimpBeta_CRBM.txt", sep = "\t")
write.table(rhesusBeta_CRBM, "rhesusBeta_CRBM.txt", sep = "\t")

#Identify aDMPs & aDMRs
#ID aDMPs
##########
#a : human
##########
#1 : set up model design and contrasts
human_design <- model.matrix(~0 + human_CRBM_sample_ages)
colnames(human_design) <- c("old", "young")
human_contr <- makeContrasts(old-young, levels = human_design)

#2 : first calculate basic stats and annotate probes)
CRBM_human_stats <- data.frame(matrix(ncol = 0, nrow = length(rownames(humanBeta_CRBM))))
rownames(CRBM_human_stats) <- rownames(humanBeta_CRBM)
CRBM_human_stats$young_mean <- rowMeans(humanBeta_CRBM[,human_CRBM_samples[1:4]])
CRBM_human_stats$old_mean <- rowMeans(humanBeta_CRBM[,human_CRBM_samples[5:7]])
CRBM_human_stats$deltaBeta <- abs(CRBM_human_stats$young_mean - CRBM_human_stats$old_mean)

#combine with illumina annotations (leaving off that added column called "row.names" that is added)
CRBM_human_stats_info <- merge(CRBM_human_stats, probe.features, by = "row.names")
rownames(CRBM_human_stats_info) <- CRBM_human_stats_info$Row.names
CRBM_human_stats_info <- CRBM_human_stats_info[2:15]

#3 : lmFit
human_CRBM_fit <- lmFit(humanBeta_CRBM, human_design)
human_CRBM_fit2 <- contrasts.fit(human_CRBM_fit, human_contr)
human_CRBM_efit <- eBayes(human_CRBM_fit2)
human_CRBM_DMP_table <- topTable(human_CRBM_efit, p.value = 1, number = length(rownames(humanBeta_CRBM)))

#merge DMP info with CpG info
human_CRBM_aDMP_info <- merge(CRBM_human_stats_info, human_CRBM_DMP_table, by = "row.names")
#changing this colname back and adding CpGs back again to row names
rownames(human_CRBM_aDMP_info) <- human_CRBM_aDMP_info$Row.names
human_CRBM_aDMP_info <- human_CRBM_aDMP_info[2:length(colnames(human_CRBM_aDMP_info))]

#4 : filter for adjusted p-value and delteBeta > 0.15
sig_human_CRBM_aDMPs <- subset(human_CRBM_aDMP_info, human_CRBM_aDMP_info$adj.P.Val <= 0.05 & abs(human_CRBM_aDMP_info$deltaBeta) >= 0.15)
write.table(sig_human_CRBM_aDMPs, "sig_human_CRBM_aDMPs.txt", sep = "\t")

##########
#b : chimp
##########
#1 : set up model design and contrasts
chimp_design <- model.matrix(~0 + chimp_CRBM_sample_ages)
colnames(chimp_design) <- c("old", "young")
chimp_contr <- makeContrasts(old-young, levels = chimp_design)

#2 : first calculate basic stats and annotate probes
CRBM_chimp_stats <- data.frame(matrix(ncol = 0, nrow = length(rownames(chimpBeta_CRBM))))
rownames(CRBM_chimp_stats) <- rownames(chimpBeta_CRBM)
CRBM_chimp_stats$young_mean <- rowMeans(chimpBeta_CRBM[,chimp_CRBM_samples[1:4]])
CRBM_chimp_stats$old_mean <- rowMeans(chimpBeta_CRBM[,chimp_CRBM_samples[5:8]])
CRBM_chimp_stats$deltaBeta <- abs(CRBM_chimp_stats$young_mean - CRBM_chimp_stats$old_mean)

#combine with illumina annotations (leaving off that added column called "row.names" that it adds)
CRBM_chimp_stats_info <- merge(CRBM_chimp_stats, probe.features, by = "row.names")
rownames(CRBM_chimp_stats_info) <- CRBM_chimp_stats_info$Row.names
CRBM_chimp_stats_info <- CRBM_chimp_stats_info[2:15]

#3 : lmFit
chimp_CRBM_fit <- lmFit(chimpBeta_CRBM, chimp_design)
chimp_CRBM_fit2 <- contrasts.fit(chimp_CRBM_fit, chimp_contr)
chimp_CRBM_efit <- eBayes(chimp_CRBM_fit2)
chimp_CRBM_DMP_table <- topTable(chimp_CRBM_efit, p.value = 1, number = length(rownames(chimpBeta_CRBM)))

#merge DMP info with CpG info
chimp_CRBM_aDMP_info <- merge(CRBM_chimp_stats_info, chimp_CRBM_DMP_table, by = "row.names")
#changing this colname back and adding CpGs back again to row names since merge stupidly removes row names and alters the colname
rownames(chimp_CRBM_aDMP_info) <- chimp_CRBM_aDMP_info$Row.names
chimp_CRBM_aDMP_info <- chimp_CRBM_aDMP_info[2:length(colnames(chimp_CRBM_aDMP_info))]

#4 : filter sig DMPs and the ones that have a diffBeta > 0.15
sig_chimp_CRBM_aDMPs <- subset(chimp_CRBM_aDMP_info, chimp_CRBM_aDMP_info$adj.P.Val <= 0.05 & abs(chimp_CRBM_aDMP_info$deltaBeta) >= 0.15)
write.table(sig_chimp_CRBM_aDMPs, "sig_chimp_CRBM_aDMPs.txt", sep = "\t")

##########
#c : rhesus
##########
#1 : set up model design and contrasts
rhesus_design <- model.matrix(~0 + macaque_CRBM_samples_ages)
colnames(rhesus_design) <- c("old", "young")
rhesus_contr <- makeContrasts(old-young, levels = rhesus_design)

#2 : first, calculate average meth for each probe for each group and deltaBeta between groups
CRBM_rhesus_stats <- data.frame(matrix(ncol = 0, nrow = length(rownames(rhesusBeta_CRBM))))
rownames(CRBM_rhesus_stats) <- rownames(rhesusBeta_CRBM)
CRBM_rhesus_stats$young_mean <- rowMeans(rhesusBeta_CRBM[,rhesus_CRBM_samples[c(7,1:3)]])
CRBM_rhesus_stats$old_mean <- rowMeans(rhesusBeta_CRBM[,rhesus_CRBM_samples[4:6]])
CRBM_rhesus_stats$deltaBeta <- abs(CRBM_rhesus_stats$young_mean - CRBM_rhesus_stats$old_mean)

#combine with illumina annotations (leaving off that added column called "row.names" that is added)
CRBM_rhesus_stats_info <- merge(CRBM_rhesus_stats, probe.features, by = "row.names")
rownames(CRBM_rhesus_stats_info) <- CRBM_rhesus_stats_info$Row.names
CRBM_rhesus_stats_info <- CRBM_rhesus_stats_info[2:15]

#3 : lmFit
rhesus_CRBM_fit <- lmFit(rhesusBeta_CRBM, rhesus_design)
rhesus_CRBM_fit2 <- contrasts.fit(rhesus_CRBM_fit, rhesus_contr)
rhesus_CRBM_efit <- eBayes(rhesus_CRBM_fit2)
rhesus_CRBM_DMP_table <- topTable(rhesus_CRBM_efit, p.value = 1, number = length(rownames(rhesusBeta_CRBM)))

#merge DMP info with CpG info
rhesus_CRBM_aDMP_info <- merge(CRBM_rhesus_stats_info, rhesus_CRBM_DMP_table, by = "row.names")
#changing this colname back and adding CpGs back again to row names since merge stupidly removes row names and alters the colname
rownames(rhesus_CRBM_aDMP_info) <- rhesus_CRBM_aDMP_info$Row.names
rhesus_CRBM_aDMP_info <- rhesus_CRBM_aDMP_info[2:length(colnames(rhesus_CRBM_aDMP_info))]

#4 : pull out the sig DMPs that have a diffBeta > 0.15
sig_rhesus_CRBM_aDMPs <- subset(rhesus_CRBM_aDMP_info, rhesus_CRBM_aDMP_info$adj.P.Val <= 0.05 & abs(rhesus_CRBM_aDMP_info$deltaBeta) >= 0.15)
write.table(sig_rhesus_CRBM_aDMPs, "sig_rhesus_CRBM_aDMPs.txt", sep = "\t")

#rm redundant objects
rm(human_CRBM_DMP_table)
rm(chimp_CRBM_DMP_table)
rm(rhesus_CRBM_DMP_table)
rm(CRBM_human_stats)
rm(CRBM_chimp_stats)
rm(CRBM_rhesus_stats)

#################
#d : see whether there is overlap among aDMPs in species
#################
#CM
intersect(rownames(sig_rhesus_CRBM_aDMPs), rownames(sig_chimp_CRBM_aDMPs))
#HM
intersect(rownames(sig_rhesus_CRBM_aDMPs), rownames(sig_human_CRBM_aDMPs))
#HC
intersect(rownames(sig_human_CRBM_aDMPs), rownames(sig_chimp_CRBM_aDMPs))

#################
#e : identify & visualize DMRs
#################
#1 : cpg.annotate
human_CRBM_DMRcate_annotation <- cpg.annotate("array", humanBeta_CRBM, arraytype = "EPIC", analysis.type = "differential", design = human_design, contrasts = TRUE, cont.matrix = human_contr, coef = "old - young")
chimp_CRBM_DMRcate_annotation <- cpg.annotate("array", chimpBeta_CRBM, arraytype = "EPIC", analysis.type = "differential", design = chimp_design, contrasts = TRUE, cont.matrix = chimp_contr, coef = "old - young")
rhesus_CRBM_DMRcate_annotation <- cpg.annotate("array", rhesusBeta_CRBM, arraytype = "EPIC", analysis.type = "differential", design = rhesus_design, contrasts = TRUE, cont.matrix = rhesus_contr, coef = "old - young")

#2 : DMRcate
human_CRBM_DMRcate_DMRs <- dmrcate(human_CRBM_DMRcate_annotation, lambda=1000, C=2, min.cpgs = 5, betacutoff = .15)
chimp_CRBM_DMRcate_DMRs <- dmrcate(chimp_CRBM_DMRcate_annotation, lambda=1000, C=2, min.cpgs = 5, betacutoff = .15)
rhesus_CRBM_DMRcate_DMRs <- dmrcate(rhesus_CRBM_DMRcate_annotation, lambda=1000, C=2, min.cpgs = 5, betacutoff = .15)

#visualize human DMRs (none in any species, so skipping)

#################
#III: plot (top) aDMPs across both regions in all species
#################
#a : chimp
#################
#1 : pull out beta values for aDMPs
#get beta for DLPFC
chimpBeta_DLPFC_aDMPs <- as.data.frame(chimpBeta_DLPFC[c(intersect(row.names(sig_chimp_DLPFC_aDMPs), row.names(sig_chimp_CRBM_aDMPs)),setdiff(row.names(sig_chimp_DLPFC_aDMPs), row.names(sig_chimp_CRBM_aDMPs)), setdiff(row.names(sig_chimp_CRBM_aDMPs), row.names(sig_chimp_DLPFC_aDMPs))),])
#get beta for CRBM
chimpBeta_CRBM_aDMPs <- as.data.frame(chimpBeta_CRBM[c(intersect(row.names(sig_chimp_DLPFC_aDMPs), row.names(sig_chimp_CRBM_aDMPs)),setdiff(row.names(sig_chimp_DLPFC_aDMPs), row.names(sig_chimp_CRBM_aDMPs)), setdiff(row.names(sig_chimp_CRBM_aDMPs), row.names(sig_chimp_DLPFC_aDMPs))),])

#create a vector of whether the aDMPs are shared, DLPFC-specific, or CRBM-specific
chimp_aDMP_region_info = c(replicate(length(intersect(row.names(sig_chimp_DLPFC_aDMPs), row.names(sig_chimp_CRBM_aDMPs))), "Shared"), replicate(length(setdiff(row.names(sig_chimp_DLPFC_aDMPs), row.names(sig_chimp_CRBM_aDMPs))), "DLPFC-specific"),replicate(length(setdiff(row.names(sig_chimp_CRBM_aDMPs), row.names(sig_chimp_DLPFC_aDMPs))), "CRBM-specific")) 
chimp_aDMP_region_info_df <- data.frame("CpG" = rownames(chimpBeta_CRBM_aDMPs), "region" = chimp_aDMP_region_info)
#reorder levels for region
chimp_aDMP_region_info_df$CpG <- factor(chimp_aDMP_region_info_df$CpG, levels = rownames(chimpBeta_CRBM_aDMPs))

#combine dataframe
chimpBeta_DLPFC_CRBM_aDMPs <- cbind(chimpBeta_DLPFC_aDMPs,chimpBeta_CRBM_aDMPs)

#melt and include info on which brain region the aDMPs are specific to
mt.chimpBeta_DLPFC_CRBM_aDMPs <- data.frame(t(data.frame(chimpBeta_DLPFC_CRBM_aDMPs))) %>% add_column("brain_region" = c("DLPFC","DLPFC","DLPFC","DLPFC","DLPFC","DLPFC","DLPFC","DLPFC","CRBM","CRBM","CRBM","CRBM","CRBM","CRBM","CRBM","CRBM")) %>% add_column("age" = c(chimp_DLPFC_sample_ages, chimp_CRBM_sample_ages)) %>% reshape2::melt() %>% setNames(., c("brain_region","age","CpG","beta")) %>% right_join(chimp_aDMP_region_info_df, by = "CpG")

#2 : plot
chimpBeta_aDMPs_plot_1 <- ggplot(data = mt.chimpBeta_DLPFC_CRBM_aDMPs, aes(x = CpG, y = beta, color = age, group = brain_region, shape = brain_region)) + geom_point(position=position_dodge(width=0.3), size = 1) + theme_bw() + ylab("Proportion methylated") + xlab("CpG") + theme(axis.text.x = element_text(angle = 45, hjust = 1)) + scale_y_continuous(limit = c(-0.015, 1.015)) + theme(plot.margin = unit(c(1, 6.55, 1, 1), 'lines'), legend.position = c(1.1, 0.73)) + scale_shape_discrete(name = "Brain region") + scale_color_discrete(name = "Age group")
chimpBeta_aDMPs_plot_2 <- ggplot(data = mt.chimpBeta_DLPFC_CRBM_aDMPs, aes(x = CpG, y = beta, group = brain_region, shape = brain_region)) + theme_bw() + ylab("Proportion methylated") + xlab("CpG") + theme(axis.text.x = element_text(angle = 45, hjust = 1)) + geom_path(data = mt.chimpBeta_DLPFC_CRBM_aDMPs, aes(x = CpG, y = -0.015, color = region), size = 3.4) + geom_point(data = mt.chimpBeta_DLPFC_CRBM_aDMPs, aes(x = CpG, y = -0.015, color = region), size = 3, shape = "square") + theme_bw() + theme(axis.text.x = element_text(angle = 45, hjust = 1)) + ylim(-0.015,1.015) + theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), panel.background = element_rect(fill = "transparent",colour = NA), plot.background = element_rect(fill = "transparent",colour = NA), plot.margin = unit(c(1, 6.55, 1, 1), 'lines'), legend.position = c(1.14, 0.32)) + scale_color_manual(name = "aDMP region", values = c("Shared" = "#00BA38", "DLPFC-specific" = "#F564E3", "CRBM-specific" = "#619CFF"))
chimpBeta_aDMPs_aligned_plots <- align_plots(chimpBeta_aDMPs_plot_1, chimpBeta_aDMPs_plot_2, align = "hv", axis = "tblr")
chimpBeta_aDMPs_combined_plots <- ggdraw(chimpBeta_aDMPs_aligned_plots[[1]]) + draw_plot(chimpBeta_aDMPs_aligned_plots[[2]])
ggsave(chimpBeta_aDMPs_combined_plots, filename = "chimpBeta_aDMPs_combined_plots.png", device = "png", height = 4.5, width = 7)

#################
#b : rhesus
#################
#since there are more in rhesus, just going to do the top 10 in each region
#1 : combine the sig probes from both regions
#make dataframe of the ones from each region that are not shared
sig_rhesus_aDMPs_CRBM_specific <- setdiff(rownames(sig_rhesus_CRBM_aDMPs), rownames(sig_rhesus_DLPFC_aDMPs))
#2 : get DMPs info
sig_rhesus_aDMPs_CRBM_specific_info <- sig_rhesus_CRBM_aDMPs[sig_rhesus_aDMPs_CRBM_specific,]
#add region column
sig_rhesus_aDMPs_CRBM_specific_info$region <- replicate(length(rownames(sig_rhesus_aDMPs_CRBM_specific_info)), "CRBM-specific")
sig_rhesus_aDMPs_DLPFC_specific <- setdiff(rownames(sig_rhesus_DLPFC_aDMPs), rownames(sig_rhesus_CRBM_aDMPs))
sig_rhesus_aDMPs_DLPFC_specific_info <- sig_rhesus_DLPFC_aDMPs[sig_rhesus_aDMPs_DLPFC_specific,]
sig_rhesus_aDMPs_DLPFC_specific_info$region <- replicate(length(rownames(sig_rhesus_aDMPs_DLPFC_specific_info)), "DLPFC-specific")
#get info from each regions for shared aDMPs
sig_rhesus_aDMPs_shared_DLPFC_info <- sig_rhesus_DLPFC_aDMPs[intersect(rownames(sig_rhesus_CRBM_aDMPs), rownames(sig_rhesus_DLPFC_aDMPs)),]
sig_rhesus_aDMPs_shared_CRBM_info <- sig_rhesus_CRBM_aDMPs[intersect(rownames(sig_rhesus_CRBM_aDMPs), rownames(sig_rhesus_DLPFC_aDMPs)),]
#adding "shared" col
sig_rhesus_aDMPs_shared_CRBM_info$region <- replicate(length(rownames(sig_rhesus_aDMPs_shared_CRBM_info)), "Shared")

#combine
sig_rhesus_combined_aDMPs <- rbind(sig_rhesus_aDMPs_DLPFC_specific_info,sig_rhesus_aDMPs_CRBM_specific_info,sig_rhesus_aDMPs_shared_CRBM_info)
top10_sig_rhesus_combined_aDMPs <- head(sig_rhesus_combined_aDMPs[order(sig_rhesus_combined_aDMPs$adj.P.Val),], n = 10)
#reorder so that grouped by region and shared are first
top10_sig_rhesus_combined_aDMPs <- top10_sig_rhesus_combined_aDMPs[order(top10_sig_rhesus_combined_aDMPs$region, decreasing = T),]

#3 : get beta for DLPFC
rhesusBeta_DLPFC_top_aDMPs <- as.data.frame(rhesusBeta_DLPFC[rownames(top10_sig_rhesus_combined_aDMPs),])
#get beta for CRBM
rhesusBeta_CRBM_top_aDMPs <- as.data.frame(rhesusBeta_CRBM[rownames(top10_sig_rhesus_combined_aDMPs),])
#combine dataframe
rhesusBeta_DLPFC_CRBM_top_aDMPs <- cbind(rhesusBeta_DLPFC_top_aDMPs,rhesusBeta_CRBM_top_aDMPs)

#create a vector of whether the top aDMPs are shared, DLPFC-specific, or CRBM-specific
rhesus_top_aDMP_region_info_df <- data.frame("CpG" = rownames(top10_sig_rhesus_combined_aDMPs), "region" = top10_sig_rhesus_combined_aDMPs$region)

#reorder levels for region so that are not ordered by CpG name but by the order of region
rhesus_top_aDMP_region_info_df$CpG <- factor(rhesus_top_aDMP_region_info_df$CpG, levels = rownames(top10_sig_rhesus_combined_aDMPs))

#melt and include info on which region the top_aDMPs are specific to
mt.rhesusBeta_DLPFC_CRBM_top_aDMPs <- data.frame(t(data.frame(rhesusBeta_DLPFC_CRBM_top_aDMPs))) %>% add_column("brain_region" = c("DLPFC","DLPFC","DLPFC","DLPFC","DLPFC","DLPFC","DLPFC","CRBM","CRBM","CRBM","CRBM","CRBM","CRBM","CRBM")) %>% add_column("age" = c(rhesus_DLPFC_samples_ages, rhesus_CRBM_samples_ages)) %>% reshape2::melt() %>% setNames(., c("brain_region","age","CpG","beta")) %>% right_join(rhesus_top_aDMP_region_info_df, by = "CpG")

#4 : plot
rhesusBeta_top_aDMPs_plot_1 <- ggplot(data = mt.rhesusBeta_DLPFC_CRBM_top_aDMPs, aes(x = CpG, y = beta, color = age, group = brain_region, shape = brain_region)) + geom_point(position=position_dodge(width=0.3), size = 1) + theme_bw() + ylab("Proportion methylated") + xlab("CpG") + theme(axis.text.x = element_text(angle = 45, hjust = 1)) + scale_y_continuous(limit = c(-0.015, 1.015)) + theme(plot.margin = unit(c(1, 6.55, 1, 1), 'lines'), legend.position = c(1.1, 0.73)) + scale_shape_discrete(name = "Brain region") + scale_color_discrete(name = "Age group")
rhesusBeta_top_aDMPs_plot_2 <- ggplot(data = mt.rhesusBeta_DLPFC_CRBM_top_aDMPs, aes(x = CpG, y = beta, group = brain_region, shape = brain_region)) + theme_bw() + ylab("Proportion methylated") + xlab("CpG") + theme(axis.text.x = element_text(angle = 45, hjust = 1)) + geom_path(data = mt.rhesusBeta_DLPFC_CRBM_top_aDMPs, aes(x = CpG, y = -0.015, color = region), size = 3.4) + geom_point(data = mt.rhesusBeta_DLPFC_CRBM_top_aDMPs, aes(x = CpG, y = -0.015, color = region), size = 3, shape = "square") + theme_bw() + theme(axis.text.x = element_text(angle = 45, hjust = 1)) + ylim(-0.015,1.015) + theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), panel.background = element_rect(fill = "transparent",colour = NA), plot.background = element_rect(fill = "transparent",colour = NA), plot.margin = unit(c(1, 6.55, 1, 1), 'lines'), legend.position = c(1.14, 0.32)) + scale_color_manual(name = "aDMP region", values = c("Shared" = "#00BA38", "DLPFC-specific" = "#F564E3", "CRBM-specific" = "#619CFF"))
rhesusBeta_top_aDMPs_aligned_plots <- align_plots(rhesusBeta_top_aDMPs_plot_1, rhesusBeta_top_aDMPs_plot_2, align = "hv", axis = "tblr")
rhesusBeta_top_aDMPs_combined_plots <- ggdraw(rhesusBeta_top_aDMPs_aligned_plots[[1]]) + draw_plot(rhesusBeta_top_aDMPs_aligned_plots[[2]])
ggsave(rhesusBeta_top_aDMPs_combined_plots, filename = "rhesusBeta_top_aDMPs_combined_plots.png", device = "png", height = 4.5, width = 7)

#################
#c : human
#################
#there are none for CRBM, so this is just the ones for DLPFC, but includes beta for both
#1 : get the top ten aDMPs from data
top10_aDMPs_human_DLPFC <- rownames(head(sig_human_DLPFC_aDMPs[order(sig_human_DLPFC_aDMPs$adj.P.Val),], n = 10))

#2 : get the beta data
#get beta for DLPFC
humanBeta_DLPFC_aDMPs <- as.data.frame(humanBeta_DLPFC[top10_aDMPs_human_DLPFC,])
#get beta for CRBM
humanBeta_CRBM_aDMPs <- as.data.frame(humanBeta_CRBM[top10_aDMPs_human_DLPFC,])

#combine dataframe
humanBeta_DLPFC_CRBM_aDMPs <- cbind(humanBeta_DLPFC_aDMPs,humanBeta_CRBM_aDMPs)

#create a vector of whether the aDMPs are shared, DLPFC-specific, or CRBM-specific - although they are all going to be "DLPFC-specific"
human_aDMP_region_info = c(replicate(length(top10_aDMPs_human_DLPFC), "DLC-specific"))
human_aDMP_region_info_df <- data.frame("CpG" = rownames(humanBeta_CRBM_aDMPs), "region" = human_aDMP_region_info)
#reorder levels for region so that are not ordered by CpG name but by the order I want
human_aDMP_region_info_df$CpG <- factor(human_aDMP_region_info_df$CpG, levels = rownames(humanBeta_CRBM_aDMPs))

#melt and include info on which region the aDMPs are specific to
mt.humanBeta_DLPFC_CRBM_aDMPs <- data.frame(t(data.frame(humanBeta_DLPFC_CRBM_aDMPs))) %>% add_column("brain_region" = c("DLPFC","DLPFC","DLPFC","DLPFC","DLPFC","DLPFC","DLPFC","CRBM","CRBM","CRBM","CRBM","CRBM","CRBM","CRBM")) %>% add_column("age" = c(human_DLPFC_sample_ages, human_CRBM_sample_ages)) %>% reshape2::melt() %>% setNames(., c("brain_region","age","CpG","beta")) %>% right_join(human_aDMP_region_info_df, by = "CpG")

#3 : plot
humanBeta_aDMPs_plot_1 <- ggplot(data = mt.humanBeta_DLPFC_CRBM_aDMPs, aes(x = CpG, y = beta, color = age, group = brain_region, shape = brain_region)) + geom_point(position=position_dodge(width=0.3), size = 1) + theme_bw() + ylab("Proportion methylated") + xlab("CpG") + theme(axis.text.x = element_text(angle = 45, hjust = 1)) + scale_y_continuous(limit = c(-0.015, 1.015)) + theme(plot.margin = unit(c(1, 6.55, 1, 1), 'lines'), legend.position = c(1.1, 0.73)) + scale_shape_discrete(name = "Brain region") + scale_color_discrete(name = "Age group")
humanBeta_aDMPs_plot_2 <- ggplot(data = mt.humanBeta_DLPFC_CRBM_aDMPs, aes(x = CpG, y = beta, group = brain_region, shape = brain_region)) + theme_bw() + ylab("Proportion methylated") + xlab("CpG") + theme(axis.text.x = element_text(angle = 45, hjust = 1)) + geom_path(data = mt.humanBeta_DLPFC_CRBM_aDMPs, aes(x = CpG, y = -0.015, color = region), size = 3.4) + geom_point(data = mt.humanBeta_DLPFC_CRBM_aDMPs, aes(x = CpG, y = -0.015, color = region), size = 3, shape = "square") + theme_bw() + theme(axis.text.x = element_text(angle = 45, hjust = 1)) + ylim(-0.015,1.015) + theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), panel.background = element_rect(fill = "transparent",colour = NA), plot.background = element_rect(fill = "transparent",colour = NA), plot.margin = unit(c(1, 6.55, 1, 1), 'lines'), legend.position = c(1.14, 0.32)) + scale_color_manual(name = "aDMP region", values = c("#F564E3"))
humanBeta_aDMPs_aligned_plots <- align_plots(humanBeta_aDMPs_plot_1, humanBeta_aDMPs_plot_2, align = "hv", axis = "tblr")
humanBeta_aDMPs_combined_plots <- ggdraw(humanBeta_aDMPs_aligned_plots[[1]]) + draw_plot(humanBeta_aDMPs_aligned_plots[[2]])
ggsave(humanBeta_aDMPs_combined_plots, filename = "humanBeta_aDMPs_combined_plots.png", device = "png", height = 4.5, width = 7)


###################
#E : apply epigenetic age calculator!
#I : preprocess 
#a : read in chimp and human data only (fewer probes lost from reading in with rhesus macaque, which is not inluded in this analysis)
chimp_baseDir <- "/chimp"
human_baseDir <- "/human"

#load data
#note that this also applied to filtering. 
#This removes probes:
#with intensities with sig detection p-vals
#with <3 beads in at least 5% of samples per probe
#non-CpG probes
#containing known SNPs
#on X and Y chr
#probes that align to more than one place in the genome
myHumanLoad <- champ.load(human_baseDir,arraytype="EPIC")
myChimpLoad <- champ.load(chimp_baseDir,arraytype="EPIC")

#b : normalize
humanBeta <- champ.norm(beta = myHumanLoad$beta,method="BMIQ")
chimpBeta <- champ.norm(beta = myChimpLoad$beta,method="BMIQ")

write.table(humanBeta, "human_full_beta.txt", sep = "\t")

#c : set up data frame to hold results
human_pd <- subset(data$pd, data$pd$Species == "Homo_sapiens")
chimp_pd <- subset(data$pd, data$pd$Species == "Pan_troglodytes")

clockResultsHuman <- data.frame(SampleID = human_pd$Sample_Name, IndividualID = human_pd$person, Region = human_pd$Region, ChrAge = human_pd$age)
clockResultsChimp <- data.frame(SampleID = chimp_pd$Sample_Name, IndividualID = chimp_pd$person, Region = chimp_pd$Region, ChrAge = chimp_pd$age)

chimpBeta <- subset(chimpBeta, rownames(chimpBeta) %in% chimpCompProbes)
write.table(chimpBeta, "chimp_full_comp_beta.txt", sep = "\t")

#d : transpose beta matrices
t.humanBeta = as.data.frame(t(humanBeta))
t.chimpBeta = as.data.frame(t(chimpBeta))

######################
#II : CLOCK
######################
#HOVATH CLOCK
#################
#a : read in Horvath clock
HorvathClock <- read.csv("AdditionalFile3.csv")

#b : define function to untransform ages for Horvath clock
anti.F = function(x,adult.age=20) { ifelse(x<0, (1+adult.age)*exp(x)-1, (1+adult.age)*x+adult.age) }

#c : prepare data for clock
#identify any missing clock probes
missingHorvathProbesHuman <- as.character(HorvathClock$CpGmarker[-1][!(as.character(HorvathClock$CpGmarker[-1]) %in% dimnames(t.humanBeta)[[2]])])
missingHorvathProbesChimp <- as.character(HorvathClock$CpGmarker[-1][!(as.character(HorvathClock$CpGmarker[-1]) %in% dimnames(t.chimpBeta)[[2]])])

#add zeros for all missing
t.humanBetaMissing <- t.humanBeta
t.humanBetaMissing[,missingHorvathProbesHuman] <- 0

t.chimpBetaMissing <- t.chimpBeta
t.chimpBetaMissing[,missingHorvathProbesChimp] <- 0

#get which CpGs in data match CpGs in clock
HorvathSelectCpGsClockHuman=is.element(dimnames(t.humanBetaMissing)[[2]], as.character(HorvathClock$CpGmarker[-1]))
HorvathSelectCpGsClockChimp=is.element(dimnames(t.chimpBetaMissing)[[2]], as.character(HorvathClock$CpGmarker[-1]))

#pull out data for these
datMethClockHorvathHuman=data.frame(t.humanBetaMissing[,HorvathSelectCpGsClockHuman])
datMethClockHorvathChimp=data.frame(t.chimpBetaMissing[,HorvathSelectCpGsClockChimp])

#reorder so can be multiplied
datMethClockHorvathHuman = data.frame(datMethClockHorvathHuman[ as.character(HorvathClock$CpGmarker[-1])])
datMethClockHorvathChimp = data.frame(datMethClockHorvathChimp[ as.character(HorvathClock$CpGmarker[-1])])

#d : run prediction equation
HorvathPredictedAgeHuman=as.numeric(anti.F(HorvathClock$CoefficientTraining[1]+as.matrix(datMethClockHorvathHuman)%*% as.numeric(HorvathClock$CoefficientTraining[-1])))
HorvathPredictedAgeChimp=as.numeric(anti.F(HorvathClock$CoefficientTraining[1]+as.matrix(datMethClockHorvathChimp)%*% as.numeric(HorvathClock$CoefficientTraining[-1])))

#add predicted ages to results df
clockResultsHuman$DNAmAge_Horvath <- HorvathPredictedAgeHuman
clockResultsChimp$DNAmAge_Horvath <- HorvathPredictedAgeChimp

#e : explore results
#add deviation and absolute deviation to results
clockResultsHuman <- transform(clockResultsHuman, deviation_Horvath = ChrAge - DNAmAge_Horvath)
clockResultsHuman <- transform(clockResultsHuman, absDev_Horvath = abs(deviation_Horvath))

clockResultsChimp <- transform(clockResultsChimp, deviation_Horvath = ChrAge - DNAmAge_Horvath)
clockResultsChimp <- transform(clockResultsChimp, absDev_Horvath = abs(deviation_Horvath))

#get mean and median absDev
Human_mean_dev_Horvath <- mean(clockResultsHuman$absDev_Horvath)
Human_median_dev_Horvath <- median(clockResultsHuman$absDev_Horvath)

Chimp_mean_dev_Horvath <- mean(clockResultsChimp$absDev_Horvath)
Chimp_median_dev_Horvath <- median(clockResultsChimp$absDev_Horvath)

#correlations:
Horvath_Human_corr <- cor(clockResultsHuman$ChrAge, clockResultsHuman$DNAmAge_Horvath, method = "pearson")
Horvath_Chimp_corr <- cor(clockResultsChimp$ChrAge, clockResultsChimp$DNAmAge_Horvath, method = "pearson")

#get region-specific measures
#human
human_median_dev_Horvath_DLPFC <- median(subset(clockResultsHuman, clockResultsHuman$Region == "DLPFC")$absDev_Horvath)
human_mean_dev_Horvath_DLPFC <- mean(subset(clockResultsHuman, clockResultsHuman$Region == "DLPFC")$absDev_Horvath)
human_median_dev_Horvath_CRBM <- median(subset(clockResultsHuman, clockResultsHuman$Region == "CRBM")$absDev_Horvath)
human_mean_dev_Horvath_CRBM <- mean(subset(clockResultsHuman, clockResultsHuman$Region == "CRBM")$absDev_Horvath)

#chimp
chimp_median_dev_Horvath_DLPFC <- median(subset(clockResultsChimp, clockResultsChimp$Region == "DLPFC")$absDev_Horvath)
chimp_mean_dev_Horvath_DLPFC <- mean(subset(clockResultsChimp, clockResultsChimp$Region == "DLPFC")$absDev_Horvath)
chimp_median_dev_Horvath_CRBM <- median(subset(clockResultsChimp, clockResultsChimp$Region == "CRBM")$absDev_Horvath)
chimp_mean_dev_Horvath_CRBM <- mean(subset(clockResultsChimp, clockResultsChimp$Region == "CRBM")$absDev_Horvath)

#f : plots
Horvath_human_plot_region <- ggplot(data = clockResultsHuman, aes(y = as.numeric(as.character(clockResultsHuman$DNAmAge_Horvath)), x = as.numeric(as.character(clockResultsHuman$ChrAge)))) + geom_point(aes(y = as.numeric(as.character(clockResultsHuman$DNAmAge_Horvath)), x = as.numeric(as.character(clockResultsHuman$ChrAge)), color = as.character(clockResultsHuman$IndividualID), shape = as.character(clockResultsHuman$Region))) + ylab("Predicted Age") + xlab("Known Age") + scale_x_continuous(breaks = seq(0, 75, by = 10)) + scale_y_continuous(breaks = seq(0, 75, by = 10)) + theme_bw() + theme(panel.grid.minor = element_blank()) + labs(color = "Individual ID") + labs(shape = "Region") + scale_shape_discrete(labels = c("CRBM","DLPFC")) + geom_smooth(aes(linetype = Region), method = "lm", se = FALSE, size = .75, color = "darkgray") + theme(axis.title.x = element_text(size = 14)) + theme(axis.title.y = element_text(size = 14)) + theme(axis.text.y = element_text(size = 12)) + theme(axis.text.x = element_text(size = 12)) + labs(title="Hovath Clock Age Prediction for Human Samples") + theme(plot.title = element_text(hjust = 0.5)) + theme(plot.title = element_text(size = 14, face = "bold")) + theme(legend.text = element_text(size = 12)) + theme(legend.title = element_text(size = 14, face = "bold")) + coord_cartesian(ylim = c(0, 75), xlim = c(0, 75))
ggsave(Horvath_human_plot_region, filename = "Horvath_human_plot_region.png", dpi = 600, height = 4, width = 5)

Horvath_chimp_plot_region <- ggplot(data = clockResultsChimp, aes(y = as.numeric(as.character(clockResultsChimp$DNAmAge_Horvath)), x = as.numeric(as.character(clockResultsChimp$ChrAge)))) + geom_point(aes(y = as.numeric(as.character(clockResultsChimp$DNAmAge_Horvath)), x = as.numeric(as.character(clockResultsChimp$ChrAge)), color = as.character(clockResultsChimp$IndividualID), shape = as.character(clockResultsChimp$Region))) + ylab("Predicted Age") + xlab("Known Age") + scale_x_continuous(breaks = seq(0, 75, by = 10)) + scale_y_continuous(breaks = seq(0, 75, by = 10)) + theme_bw() + theme(panel.grid.minor = element_blank()) + labs(color = "Individual ID") + labs(shape = "Region") + scale_shape_discrete(labels = c("CRBM","DLPFC")) + geom_smooth(aes(linetype = Region), method = "lm", se = FALSE, size = .75, color = "darkgray") + theme(axis.title.x = element_text(size = 14)) + theme(axis.title.y = element_text(size = 14)) + theme(axis.text.y = element_text(size = 12)) + theme(axis.text.x = element_text(size = 12)) + labs(title="Hovath Clock Age Prediction for Chimp Samples") + theme(plot.title = element_text(hjust = 0.5)) + theme(plot.title = element_text(size = 14, face = "bold")) + theme(legend.text = element_text(size = 12)) + theme(legend.title = element_text(size = 14, face = "bold")) + coord_cartesian(ylim = c(0, 75), xlim = c(0, 75))
ggsave(Horvath_chimp_plot_region, filename = "Horvath_chimp_plot_region.png", dpi = 600, height = 4, width = 5)

#####################
#Apply chimpanzee clock to chimpanzee samples
#################
#a : read in chimp clock
datClock <- read.csv("chimp_clock_450k.csv")

#b : prepare data
#see if any probes in the clock are missing from the data
missing.denovo <- as.character(as.character(datClock$CpG[-1][!(as.character(datClock$CpG[-1]) %in% dimnames(t.chimpBeta)[[2]])]))

#copy dataset to add in 0s
t.chimpBeta.missing.denovo <- t.chimpBeta
t.chimpBeta.missing.denovo[,missing.denovo] <- 0

#get a list of clock CpGs to select from data
Chimp_denovoSelectCpGsClock=is.element(dimnames(t.chimpBeta.missing.denovo)[[2]], as.character(datClock$CpG[-1]))

#pull out those CpGs
Chimp_datMethClockdenovo <- data.frame(t.chimpBeta.missing.denovo[,Chimp_denovoSelectCpGsClock])

#reorder to match clock to make sure the correct coefficients are multipled
setcolorder(Chimp_datMethClockdenovo, as.character(datClock$CpG[-1]))

#c : predict!
deNovoPredictedAgeChimp=as.numeric(datClock$Coefficient[1]+as.matrix(Chimp_datMethClockdenovo)%*% as.numeric(datClock$Coefficient[-1]))

#add to results
clockResultsChimp$DNAmAge_denovo <- deNovoPredictedAgeChimp
clockResultsChimp <- transform(clockResultsChimp, deviation_denovo = ChrAge - DNAmAge_denovo)
clockResultsChimp <- transform(clockResultsChimp, absDev_denovo = abs(deviation_denovo))

Chimp_mean_dev_denovo <- mean(clockResultsChimp$absDev_denovo)
Chimp_median_dev_denovo <- median(clockResultsChimp$absDev_denovo)

denovo_Chimp_corr <- cor(clockResultsChimp$ChrAge, clockResultsChimp$DNAmAge_denovo, method = "pearson")

#d : explore results
#get region-specific means and medians
chimp_median_dev_denovo_DLPFC <- median(subset(clockResultsChimp, clockResultsChimp$Region == "DLPFC")$absDev_denovo)
chimp_mean_dev_denovo_DLPFC <- mean(subset(clockResultsChimp, clockResultsChimp$Region == "DLPFC")$absDev_denovo)
chimp_median_dev_denovo_CRBM <- median(subset(clockResultsChimp, clockResultsChimp$Region == "CRBM")$absDev_denovo)
chimp_mean_dev_denovo_CRBM <- mean(subset(clockResultsChimp, clockResultsChimp$Region == "CRBM")$absDev_denovo)

#e : plot
denovo_chimp_plot_region <- ggplot(data = clockResultsChimp, aes(y = as.numeric(as.character(clockResultsChimp$DNAmAge_denovo)), x = as.numeric(as.character(clockResultsChimp$ChrAge)))) + geom_point(data = clockResultsChimp, aes(y = as.numeric(as.character(clockResultsChimp$DNAmAge_denovo)), x = as.numeric(as.character(clockResultsChimp$ChrAge)), color = as.character(clockResultsChimp$IndividualID), shape = as.character(clockResultsChimp$Region))) + ylab("Predicted Age") + xlab("Known Age") + scale_x_continuous(breaks = seq(0, 75, by = 10)) + scale_y_continuous(breaks = seq(0, 75, by = 10)) + coord_fixed() + theme_bw() + theme(panel.grid.minor = element_blank()) + labs(color = "Individual ID") + labs(shape = "Region") + scale_shape_discrete(labels = c("CRBM","DLPFC")) + geom_smooth(aes(linetype = Region), method = "lm", se = FALSE, size = .75, color = "darkgray") + theme(axis.title.x = element_text(size = 14)) + theme(axis.title.y = element_text(size = 14)) + theme(axis.text.y = element_text(size = 12)) + theme(axis.text.x = element_text(size = 12)) + labs(title="de novo Chimpanzee Clock Age Prediction for Chimp Samples") + theme(plot.title = element_text(hjust = 0.5)) + theme(plot.title = element_text(size = 14, face = "bold")) + theme(legend.text = element_text(size = 12)) + theme(legend.title = element_text(size = 14, face = "bold")) + coord_cartesian(ylim = c(0, 75), xlim = c(0, 75))
ggsave(denovo_chimp_plot_region, filename = "denovo_chimp_plot_region.png", dpi = 600, height = 4, width = 5)

#print out tables
write.table(clockResultsHuman, "clockResultsHuman.txt", sep = "\t")
write.table(clockResultsChimp, "clockResultsChimp.txt", sep = "\t")

#check whether any clock CpGs are among aDMPs
intersect(rownames(sig_human_DLPFC_aDMPs), HorvathClock$CpGmarker)
intersect(rownames(sig_rhesus_DLPFC_aDMPs), HorvathClock$CpGmarker)
intersect(rownames(sig_chimp_DLPFC_aDMPs), HorvathClock$CpGmarker)
intersect(rownames(sig_rhesus_CRBM_aDMPs), HorvathClock$CpGmarker)
intersect(rownames(sig_chimp_CRBM_aDMPs), HorvathClock$CpGmarker)

intersect(rownames(sig_human_DLPFC_aDMPs), datClock$CpG)
intersect(rownames(sig_rhesus_DLPFC_aDMPs), datClock$CpG)
intersect(rownames(sig_chimp_DLPFC_aDMPs), datClock$CpG)
intersect(rownames(sig_rhesus_CRBM_aDMPs), datClock$CpG)
intersect(rownames(sig_chimp_CRBM_aDMPs), datClock$CpG)

#remove these redundant objects to save space/memory
rm(t.humanBeta)
rm(t.chimpBeta)
rm(t.humanBetaMissing)
rm(t.chimpBetaMissing)


